@@ -1,4 +1,4 @@
-package Pcore::Redis v0.7.0;
+package Pcore::Redis v0.7.1;
 
 use Pcore -dist, -class;
 
@@ -20,7 +20,7 @@ sub run ( $self, $cb ) {
     P->file->mkdir('/tmp/redis.sock') if !-d '/tmp/redis.sock';
 
     # init log dir
-    my $log_dir = "$ENV->{LOG_DIR}";
+    my $log_dir = "$ENV->{DATA_DIR}";
 
     # run server
     P->pm->run_proc(
@@ -79,7 +79,7 @@ sub default_config ( $self ) {
         databases                   => 16,
         dbfilename                  => 'redis.rdb',
         dir                         => $data_dir,
-        logfile                     => "$ENV->{LOG_DIR}redis.log",
+        logfile                     => "$ENV->{DATA_DIR}redis.log",
         loglevel                    => 'notice',
         pidfile                     => "${data_dir}redis.pid",
         port                        => 6379,                                           # use 0 to stop TCP interface
@@ -107,8 +107,6 @@ sub default_config ( $self ) {
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
-## |    3 | 54                   | References::ProhibitDoubleSigils - Double-sigil dereference                                                    |
-## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
 ## |    3 | 98                   | ValuesAndExpressions::ProhibitInterpolationOfLiterals - Useless interpolation of literal string                |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
